﻿using System;
using System.Diagnostics;
using Pixiview.UI;
using Pixiview.Utils;
using Xamarin.Forms;

namespace Pixiview
{
    public partial class App : Application
    {
        public const string TitleButton = nameof(TitleButton);
        public const string TitleLabel = nameof(TitleLabel);

        public const string WindowColor = nameof(WindowColor);
        public const string TextColor = nameof(TextColor);
        public const string MainColor = nameof(MainColor);
        public const string MainTextColor = nameof(MainTextColor);

        public const string IconLightFontFamily = nameof(IconLightFontFamily);
        public const string IconRegularFontFamily = nameof(IconRegularFontFamily);
        public const string IconSolidFontFamily = nameof(IconSolidFontFamily);
        public const string IconLeft = nameof(IconLeft);
        public const string FontSizeTitle = nameof(FontSizeTitle);
        public const string FontSizeTitleIcon = nameof(FontSizeTitleIcon);
        //public const string Horizon10 = nameof(Horizon10);

        public App()
        {
            InitializeComponent();
            InitResources();
        }

        private void InitResources()
        {
            var p = DependencyService.Get<IEnvironmentService>().GetEnvironment();

            Resources.Add(IconLightFontFamily, p.IconLightFontFamily);
            Resources.Add(IconRegularFontFamily, p.IconRegularFontFamily);
            Resources.Add(IconSolidFontFamily, p.IconSolidFontFamily);

            Resources.Add(IconLeft, p.IconLeft);
            Resources.Add(FontSizeTitle, StyleDefinition.FontSizeTitle);
            Resources.Add(FontSizeTitleIcon, StyleDefinition.FontSizeTitleIcon);
            //Resources.Add(Horizon10, StyleDefinition.Horizon10);
        }

        protected override void OnStart()
        {
            MainPage = UIFactory.CreateNavigationPage(new MainPage());
        }

        protected override void OnSleep()
        {
        }

        protected override void OnResume()
        {
        }

        public static void DebugPrint(string message)
        {
            Debug.WriteLine("[{0:HH:mm:ss.ffff}] - {1}", DateTime.Now, message);
        }

        public static void DebugError(string category, string message)
        {
            Debug.Fail(string.Format("[{0:HH:mm:ss.ffff}] - {1} - {2}", DateTime.Now, category, message));
        }
    }
}
